@@ -32,11 +32,11 @@ from xpra.gtk_common.gtk_util import (
     enable_alpha,
     gio_File, query_info_async, load_contents_async, load_contents_finish,
     WINDOW_POPUP, WINDOW_TOPLEVEL, GRAB_STATUS_STRING, GRAB_SUCCESS,
-    SCROLL_UP, SCROLL_DOWN, SCROLL_LEFT, SCROLL_RIGHT,
+    SCROLL_UP, SCROLL_DOWN, SCROLL_LEFT, SCROLL_RIGHT, SCROLL_SMOOTH,
     DEST_DEFAULT_MOTION, DEST_DEFAULT_HIGHLIGHT, ACTION_COPY,
     BUTTON_PRESS_MASK, BUTTON_RELEASE_MASK, POINTER_MOTION_MASK,
     POINTER_MOTION_HINT_MASK, ENTER_NOTIFY_MASK, LEAVE_NOTIFY_MASK,
-    WINDOW_EVENT_MASK,
+    WINDOW_EVENT_MASK, SMOOTH_SCROLL_MASK,
     )
 from xpra.gtk_common.keymap import KEY_TRANSLATIONS
 from xpra.client.client_window_base import ClientWindowBase
@@ -225,6 +225,7 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
         self._current_frame_extents = None
         self._screen = -1
         self._frozen = False
+        self._focus_latest = None
         self.window_state_timer = None
         self.send_iconify_timer = None
         self.remove_pointer_overlay_timer = None
@@ -398,7 +399,6 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
                 log.warn("Warning: missing gdk bindings:")
                 log.warn(" %s", e)
             else:
-                self._focus_latest = None
                 grablog("adding event receiver so we can get FocusIn and FocusOut events whilst grabbing the keyboard")
                 add_event_receiver(self.get_window(), self)
         #other platforms should bet getting regular focus events instead:
@@ -1818,10 +1818,9 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
                 window.move(x+dx, y+dy)
         geomlog("configure event: current size=%s, new size=%s, backing=%s, iconified=%s",
                 self._size, (w, h), self._backing, self._iconified)
-        if (w, h) != self._size or (self._backing is None and not self._iconified):
-            self._size = (w, h)
-            self._set_backing_size(w, h)
-        elif self._backing and not self._iconified:
+        self._size = (w, h)
+        self._set_backing_size(w, h)
+        if self._backing and not self._iconified:
             geomlog("configure event: size unchanged, queueing redraw")
             self.queue_draw_area(0, 0, w, h)
 
@@ -2122,6 +2121,11 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
     def _do_scroll_event(self, event):
         if self._client.readonly:
             return
+        if ((SMOOTH_SCROLL_MASK and event.direction==SMOOTH_SCROLL_MASK) or
+            (SCROLL_SMOOTH and event.direction==SCROLL_SMOOTH)):
+            mouselog("smooth scroll event: %s", event)
+            self._client.wheel_event(self._id, event.delta_x, -event.delta_y)
+            return
         button_mapping = GDK_SCROLL_MAP.get(event.direction, -1)
         mouselog("do_scroll_event device=%s, direction=%s, button_mapping=%s",
                  self._device_info(event), event.direction, button_mapping)
