@@ -166,7 +166,7 @@ class Protocol(object):
         self.output_packetcount = 0
         self.output_raw_packetcount = 0
         #initial value which may get increased by client/server after handshake:
-        self.max_packet_size = 4*1024*1024
+        self.max_packet_size = 16*1024*1024
         self.abs_max_packet_size = 256*1024*1024
         self.large_packets = [b"hello", b"window-metadata", b"sound-data", b"notify_show", b"setting-change"]
         self.send_aliases = {}
@@ -221,12 +221,12 @@ class Protocol(object):
     def wait_for_io_threads_exit(self, timeout=None):
         io_threads = [x for x in (self._read_thread, self._write_thread) if x is not None]
         for t in io_threads:
-            if t.isAlive():
+            if t.is_alive():
                 t.join(timeout)
         exited = True
         cinfo = self._conn or "cleared connection"
         for t in io_threads:
-            if t.isAlive():
+            if t.is_alive():
                 log.warn("Warning: %s thread of %s is still alive (timeout=%s)", t.name, cinfo, timeout)
                 exited = False
         return exited
@@ -500,12 +500,15 @@ class Protocol(object):
             self.enable_compressor("none")
             return
         opts = compression.get_enabled_compressors(order=compression.PERFORMANCE_ORDER)
+        compressors = caps.strlistget("compressors")
         log("enable_compressor_from_caps(..) options=%s", opts)
         for c in opts:      #ie: [zlib, lz4, lzo]
-            if caps.boolget(c):
+            if c=="none":
+                continue
+            if c in compressors or caps.boolget(c):
                 self.enable_compressor(c)
                 return
-        log.warn("compression disabled: no matching compressor found")
+        log.warn("Warning: compression disabled, no matching compressor found")
         self.enable_compressor("none")
 
     def enable_compressor(self, compressor):
@@ -622,7 +625,7 @@ class Protocol(object):
             log.warn(" '%s' packet is %s bytes: ", packet_type, len(main_packet))
             log.warn(" argument types: %s", csv(type(x) for x in packet[1:]))
             log.warn(" sizes: %s", csv(len(strtobytes(x)) for x in packet[1:]))
-            log.warn(" packet: %s", repr_ellipsized(str(packet)))
+            log.warn(" packet: %s", repr_ellipsized(packet))
         #compress, but don't bother for small packets:
         if level>0 and len(main_packet)>min_comp_size:
             try:
@@ -978,6 +981,9 @@ class Protocol(object):
                 #make sure we get a new header next time
                 header = b""
                 if packet_index>0:
+                    if packet_index in raw_packets:
+                        self.invalid("duplicate raw packet at index %i", packet_index)
+                        return
                     #raw packet, store it and continue:
                     raw_packets[packet_index] = data
                     payload_size = -1
