@@ -15,6 +15,7 @@ from xpra.version_util import XPRA_VERSION
 from xpra.util import updict, rindex, envbool, envint, typedict, AdHocStruct
 from xpra.os_util import memoryview_to_bytes, strtobytes, bytestostr, monotonic_time
 from xpra.server import server_features
+from xpra.server.source.windows_mixin import WindowsMixin
 from xpra.gtk_common.gobject_util import one_arg_signal
 from xpra.gtk_common.gtk_util import (
     get_default_root_window, get_xwindow, pixbuf_new_from_data, is_realized,
@@ -469,8 +470,14 @@ class XpraServer(gobject.GObject, X11ServerBase):
             self._add_new_window(window)
 
         root = get_default_root_window()
-        with xsync:
-            children = get_children(root)
+        try:
+            with xsync:
+                children = get_children(root)
+        except XError:
+            log("load_existing_windows()", exc_info=True)
+            log("trying again")
+            with xsync:
+                children = get_children(root)
         for window in children:
             xid = get_xwindow(window)
             can_add = False
@@ -587,6 +594,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
         metadata = {"x11-property" : event}
         wid = self._window_to_id[window]
         for ss in self._server_sources.values():
+            if not isinstance(ss, WindowsMixin):
+                continue
             ms = getattr(ss, "metadata_supported", ())
             if "x11-property" in ms:
                 ss.send("window-metadata", wid, metadata)
@@ -636,7 +645,6 @@ class XpraServer(gobject.GObject, X11ServerBase):
             return
         x, y, nw, nh = self._desktop_manager.window_geometry(window)
         resize_counter = self._desktop_manager.get_resize_counter(window, 1)
-        from xpra.server.source.windows_mixin import WindowsMixin
         wsources = [ss for ss in self._server_sources.values() if isinstance(ss, WindowsMixin)]
         for ss in wsources:
             ss.move_resize_window(wid, window, x, y, nw, nh, resize_counter)
@@ -715,7 +723,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
         geomlog("or_window_geometry_changed: %s (window=%s)", geom, window)
         wid = self._window_to_id[window]
         for ss in self._server_sources.values():
-            ss.or_window_geometry(wid, window, x, y, w, h)
+            if isinstance(ss, WindowsMixin):
+                ss.or_window_geometry(wid, window, x, y, w, h)
 
 
     def add_control_commands(self):
@@ -736,7 +745,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
     def _show_desktop(self, wm, show):
         log("show_desktop(%s, %s)", wm, show)
         for ss in self._server_sources.values():
-            ss.show_desktop(show)
+            if isinstance(ss, WindowsMixin):
+                ss.show_desktop(show)
 
 
     def _focus(self, server_source, wid, modifiers):
@@ -802,7 +812,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
     def _send_new_tray_window_packet(self, wid, window):
         ww, wh = window.get_dimensions()
         for ss in self._server_sources.values():
-            ss.new_tray(wid, window, ww, wh)
+            if isinstance(ss, WindowsMixin):
+                ss.new_tray(wid, window, ww, wh)
         self.refresh_window(window)
 
 
@@ -825,7 +836,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
             return
         self._has_grab = grab_id
         for ss in self._server_sources.values():
-            ss.pointer_grab(self._has_grab)
+            if isinstance(ss, WindowsMixin):
+                ss.pointer_grab(self._has_grab)
 
     def _window_ungrab(self, window, event):
         grab_id = self._window_to_id.get(window, -1)
@@ -835,7 +847,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
             return
         self._has_grab = 0
         for ss in self._server_sources.values():
-            ss.pointer_ungrab(grab_id)
+            if isinstance(ss, WindowsMixin):
+                ss.pointer_ungrab(grab_id)
 
 
     def _initiate_moveresize(self, window, event):
